==> kubernetes-model-1.0.6-sources.jar: io/fabric8/kubernetes/api/model/ResourceRequirementsBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Visitable;

public class ResourceRequirementsBuilder extends ResourceRequirementsFluent<ResourceRequirementsBuilder> implements VisitableBuilder<ResourceRequirements,ResourceRequirementsBuilder>{

     ResourceRequirementsFluent<?> fluent;
public ResourceRequirementsBuilder(){
    this(new ResourceRequirements());
}
public ResourceRequirementsBuilder( ResourceRequirementsFluent<?> fluent ){
    this(fluent, new ResourceRequirements());
}
public ResourceRequirementsBuilder( ResourceRequirementsFluent<?> fluent , ResourceRequirements instance ){
    this.fluent = fluent; fluent.withLimits(instance.getLimits()); fluent.withRequests(instance.getRequests()); 
}
public ResourceRequirementsBuilder( ResourceRequirements instance ){
    this.fluent = this; this.withLimits(instance.getLimits()); this.withRequests(instance.getRequests()); 
}

public EditableResourceRequirements build(){
    EditableResourceRequirements buildable = new EditableResourceRequirements(fluent.getLimits(),fluent.getRequests());
validate(buildable);
return buildable;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.9-sources.jar: io/fabric8/kubernetes/api/model/ResourceRequirementsBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Visitable;

public class ResourceRequirementsBuilder extends ResourceRequirementsFluent<ResourceRequirementsBuilder> implements VisitableBuilder<ResourceRequirements,ResourceRequirementsBuilder>{

     ResourceRequirementsFluent<?> fluent;
public ResourceRequirementsBuilder(){
    this(new ResourceRequirements());
}
public ResourceRequirementsBuilder( ResourceRequirementsFluent<?> fluent ){
    this(fluent, new ResourceRequirements());
}
public ResourceRequirementsBuilder( ResourceRequirementsFluent<?> fluent , ResourceRequirements instance ){
    this.fluent = fluent; fluent.withLimits(instance.getLimits()); fluent.withRequests(instance.getRequests()); 
}
public ResourceRequirementsBuilder( ResourceRequirements instance ){
    this.fluent = this; this.withLimits(instance.getLimits()); this.withRequests(instance.getRequests()); 
}

public EditableResourceRequirements build(){
    EditableResourceRequirements buildable = new EditableResourceRequirements(fluent.getLimits(),fluent.getRequests());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
ResourceRequirementsBuilder that = (ResourceRequirementsBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
